@@ -185,27 +185,7 @@ void KItemListContainer::wheelEvent(QWheelEvent* event)
     KItemListSmoothScroller* smoothScroller = scrollHorizontally ?
                                               m_horizontalSmoothScroller : m_verticalSmoothScroller;
 
-    const QScrollBar* scrollBar = smoothScroller->scrollBar();
-    if (!event->pixelDelta().isNull()) {
-        const int numPixels =  event->pixelDelta().y();
-        if (event->modifiers().testFlag(Qt::ShiftModifier)) {
-            const int scrollingDirection = numPixels > 0 ? 1 : -1;
-            smoothScroller->scrollTo(scrollBar->value() - scrollBar->pageStep() * scrollingDirection);
-        } else {
-            smoothScroller->scrollTo(scrollBar->value() - numPixels);
-        }
-    } else {
-        const int numDegrees = event->angleDelta().y() / 8;
-        const int numSteps = qApp->wheelScrollLines() * numDegrees / 15;
-        if (event->modifiers().testFlag(Qt::ShiftModifier)) {
-            const int scrollingDirection = numSteps > 0 ? 1 : -1;
-            smoothScroller->scrollTo(scrollBar->value() - scrollBar->pageStep() * scrollingDirection);
-        } else {
-            smoothScroller->scrollTo(scrollBar->value() - numSteps * scrollBar->pageStep() / 12);
-        }
-    }
-
-    event->accept();
+    smoothScroller->handleWheelEvent(event);
 }
 
 void KItemListContainer::slotScrollOrientationChanged(Qt::Orientation current, Qt::Orientation previous)
